# Welcome to MkDocs

For full documentation visit [mkdocs.org](https://www.mkdocs.org).

## Notes on use with the CodeChat System
All configuration files were generated using the command `mkdocs new mkdocs`. The CodeChat project configuration file, `codechat_config.yaml`, has an `output_path` setting of `site` to match the standard mkdocs configuration.

To use these files, simply copy them to a new project directory of your choice. Open them in your preferred text editor/IDE, then use a appropriate CodeChat extension/plugin to open any of these files to build and view the results.

## Commands

* `mkdocs new [dir-name]` - Create a new project.
* `mkdocs serve` - Start the live-reloading docs server.
* `mkdocs build` - Build the documentation site.
* `mkdocs -h` - Print help message and exit.

## Project layout

    mkdocs.yml    # The configuration file.
    docs/
        index.md  # The documentation homepage.
        ...       # Other markdown pages, images and other files.
